@@ -22,25 +22,27 @@ sub new{
 }
 
 sub insert{
-	my ($self, $k,$v) = @_;
+	my ($self, $k,@v) = @_;
 	my $table = $self->table;
-	my $pos = $self->pos;
 
 	if(!defined($k)){
-		croak "insert must be called with 'key', 'value' as arguments. Key not defined.";
+		croak "insert must be called with ('key','value') as arguments. Key not defined.";
 	}
-	my $klen = length($k);
-	my $vlen = length($v);
+	
 	my ($h, $h0,$h1) = $self->hash($k);
+	my $klen = length($k);
 
 	if(!$table->[$h0]){
 		$table->[$h0] = [];
 	}
 
-	push @{$table->[$h0]},($h,$pos);
-
-	$self->write_long($klen,$vlen);
-	$self->write($k.$v,$klen+$vlen);
+	
+	for my $v (@v){
+		push @{$table->[$h0]},($h,$self->pos);
+		my $vlen = length($v);
+		$self->write_long($klen,$vlen);
+		$self->write($k.$v,$klen+$vlen);
+	}
 
 	return $self;
 }
